# Jupyter Community Call

## August 27th, 2019

**Date:** August 27, 2019, at 9am Pacific (your [timezone](https://arewemeetingyet.com/Los%20Angeles/2019-08-27/09:00/Jupyter%20Community%20Call))

**Link:** [Youtube Video](https://youtu.be/k1-1XAML9fc)

**Welcome!**

## Purpose

Think of it as a monthly, virtual JupyterCon. It’s a place to announce and share fun things happening in the Jupyter community.

For more discussion on the format of these calls, see the thread [here](https://discourse.jupyter.org/t/reviving-the-all-jupyter-team-meetings/423).

## Short reports, celebrations, shout-outs

This is a place to make *short* announcements (without a need for discussion). 

* [x] Tracking Jupyter Newsletter, [22nd edition](https://tinyletter.com/TrackingJupyter/letters/tracking-jupyter-newsletter-the-twenty-second). Thank you, Tony Hirst!
* [x] JupyterLab 1.1.0rc0 is up on PyPI and conda-forge. Please test! JupyterLab 1.1.0 will be released tomorrow.
  * `pip install --pre jupyterlab==1.1.0rc0` or 
  * `conda install -c conda-forge/label/prerelease-jupyterlab jupyterlab=1.1.0rc0`
* [ ] [name=yournamehere]

## Agenda Items

Add agenda items here **before** the meeting. We will reorganize the agenda so that it fits in the 60m meeting slot.

* [x] [name=Jupyter Cal Poly Intern Team] [Rich Text JupyterLab extension](https://github.com/jupytercalpoly/jupyterlab-richtext-mode)
* [x] [name=Jupyter Cal Poly Intern Team] [Python Package Installer JupyterLab extension](https://github.com/jupytercalpoly/jupyterlab-pkginstaller)
* [x] [name=Tony Fast] Gist to Binder
    * https://gist.github.com/Zsailer/6da0dc3c97ec873685b7fe58e52d36d7
    * People say reproducibility is hard.
    * User mybinder.org to generate a live notebook from a Gist.
    * dependencies in requirement.txt lead to a faster build.
* [x] [name=Saul Shanabrook] [JupyterLab Rich Context Extensions](https://discourse.jupyter.org/t/jupyterlab-rich-context-extensions/1350)
  * [ ] [Data registry](https://github.com/jupyterlab/jupyterlab-data-explorer) with [HDF5 Viewer](https://github.com/telamonian/jupyterlab-hdf/)
      * [ ] It's meant to make it easier to create new extensions in JupyterLab that deal with different data formats. If you have a data viewer extension, you shouldn't care if the data came from a file or from a notebook output or a database, you just want to be able to render a certain format. 
      * [ ] Able to visualize HDF5 datasets using this extension too!
  * [ ] [Metadata/linked data service](https://github.com/jupyterlab/jupyterlab-data-explorer)

## Attendees


If you are joining the Jupyter Community Call, sign in below so we know who was here.

-  Zach     | Jupyter Cal Poly          | @Zsailer        |
-  Derek    | Jupyter Cal Poly (Intern) | @dLamSlo8       |
-  Isabela  | Jupyter Cal Poly (Intern) | @isabela-pf     |
-  Marisa   | Jupyter Cal Poly (Intern) | @marisaaquilina |
-  Markelle | Jupyter Cal Poly (Intern) | @markellekelly  |
-  Javier   | Jupyter Cal Poly (Intern) | @javag97        |
-  Denton   | Project Drawdown          | @dgentry        |
-  Tony     | Quansight  | @tonyfast |
-  Chico Venancio| BMC Group K. K.| @chicocvenancio|
-  Elizabeth DuPre | McGill University | @emdupre|
-  Wayne Decatur | Upstate Medical University | @fomightez|
-  Saul Shanabrook | Quansight | @saulshanabrook |
-  Joe      | Mavenomics               | @quigleyj-mavenomics|
-  A. T. Darian   | Two Sigma          | @afshin          |
-  Erik Sundell   | Sandvik            | @consideRatio    |
-  Kevin Bates | IBM | @kevin-bates  |
